@@ -1,5 +1,12 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
+/**
+ * SECTION:retro-core-descriptor
+ * @short_description: An object describing the capabilities and requirements of a Libretro core
+ * @title: RetroCoreDescriptor
+ * @See_also: #RetroCore
+ */
+
 #include "retro-core-descriptor.h"
 
 struct _RetroCoreDescriptor
@@ -76,9 +83,8 @@ has_group_prefixed (RetroCoreDescriptor *self,
   gchar *group;
   gboolean result;
 
-  g_return_val_if_fail (RETRO_IS_CORE_DESCRIPTOR (self), FALSE);
-  g_return_val_if_fail (group_prefix != NULL, FALSE);
-  g_return_val_if_fail (group_suffix != NULL, FALSE);
+  g_assert (group_prefix != NULL);
+  g_assert (group_suffix != NULL);
 
   group = g_strconcat (group_prefix, group_suffix, NULL);
   result = g_key_file_has_group (self->key_file, group);
@@ -98,10 +104,9 @@ has_key_prefixed (RetroCoreDescriptor  *self,
   gboolean result;
   GError *tmp_error = NULL;
 
-  g_return_val_if_fail (RETRO_IS_CORE_DESCRIPTOR (self), FALSE);
-  g_return_val_if_fail (group_prefix != NULL, FALSE);
-  g_return_val_if_fail (group_suffix != NULL, FALSE);
-  g_return_val_if_fail (key != NULL, FALSE);
+  g_assert (group_prefix != NULL);
+  g_assert (group_suffix != NULL);
+  g_assert (key != NULL);
 
   group = g_strconcat (group_prefix, group_suffix, NULL);
   result = g_key_file_has_key (self->key_file,
@@ -131,10 +136,9 @@ get_string_prefixed (RetroCoreDescriptor  *self,
   gchar *result;
   GError *tmp_error = NULL;
 
-  g_return_val_if_fail (RETRO_IS_CORE_DESCRIPTOR (self), NULL);
-  g_return_val_if_fail (group_prefix != NULL, NULL);
-  g_return_val_if_fail (group_suffix != NULL, NULL);
-  g_return_val_if_fail (key != NULL, NULL);
+  g_assert (group_prefix != NULL);
+  g_assert (group_suffix != NULL);
+  g_assert (key != NULL);
 
   group = g_strconcat (group_prefix, group_suffix, NULL);
 
@@ -166,11 +170,10 @@ get_string_list_prefixed (RetroCoreDescriptor  *self,
   gchar **result;
   GError *tmp_error = NULL;
 
-  g_return_val_if_fail (RETRO_IS_CORE_DESCRIPTOR (self), NULL);
-  g_return_val_if_fail (group_prefix != NULL, NULL);
-  g_return_val_if_fail (group_suffix != NULL, NULL);
-  g_return_val_if_fail (key != NULL, NULL);
-  g_return_val_if_fail (length != NULL, NULL);
+  g_assert (group_prefix != NULL);
+  g_assert (group_suffix != NULL);
+  g_assert (key != NULL);
+  g_assert (length != NULL);
 
   group = g_strconcat (group_prefix, group_suffix, NULL);
   result = g_key_file_get_string_list (self->key_file,
@@ -191,17 +194,16 @@ get_string_list_prefixed (RetroCoreDescriptor  *self,
 }
 
 static void
-retro_core_descriptor_check_has_required_key (RetroCoreDescriptor  *self,
-                                              const gchar          *group,
-                                              const gchar          *key,
-                                              GError              **error)
+check_has_required_key (RetroCoreDescriptor  *self,
+                        const gchar          *group,
+                        const gchar          *key,
+                        GError              **error)
 {
   gboolean has_key;
   GError *tmp_error = NULL;
 
-  g_return_if_fail (RETRO_IS_CORE_DESCRIPTOR (self));
-  g_return_if_fail (group != NULL);
-  g_return_if_fail (key != NULL);
+  g_assert (group != NULL);
+  g_assert (key != NULL);
 
   has_key = g_key_file_has_key (self->key_file,
                                 RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
@@ -224,49 +226,46 @@ retro_core_descriptor_check_has_required_key (RetroCoreDescriptor  *self,
                  group);
 }
 
-// FIXME static
-void
-retro_core_descriptor_check_libretro_group (RetroCoreDescriptor  *self,
-                                            GError              **error)
+static void
+check_libretro_group (RetroCoreDescriptor  *self,
+                      GError              **error)
 {
   GError *tmp_error = NULL;
 
-  g_return_if_fail (RETRO_IS_CORE_DESCRIPTOR (self));
-
-  retro_core_descriptor_check_has_required_key (self,
-                                                RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
-                                                RETRO_CORE_DESCRIPTOR_TYPE_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
+                          RETRO_CORE_DESCRIPTOR_TYPE_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
     return;
   }
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
-                                                RETRO_CORE_DESCRIPTOR_NAME_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
+                          RETRO_CORE_DESCRIPTOR_NAME_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
     return;
   }
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
-                                                RETRO_CORE_DESCRIPTOR_MODULE_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
+                          RETRO_CORE_DESCRIPTOR_MODULE_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
     return;
   }
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
-                                                RETRO_CORE_DESCRIPTOR_LIBRETRO_VERSION_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
+                          RETRO_CORE_DESCRIPTOR_LIBRETRO_VERSION_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
@@ -274,11 +273,10 @@ retro_core_descriptor_check_libretro_group (RetroCoreDescriptor  *self,
   }
 }
 
-// FIXME static
-void
-retro_core_descriptor_check_platform_group (RetroCoreDescriptor  *self,
-                                            const gchar          *group,
-                                            GError              **error)
+static void
+check_platform_group (RetroCoreDescriptor  *self,
+                      const gchar          *group,
+                      GError              **error)
 {
   gboolean has_key;
   gchar **firmwares;
@@ -286,13 +284,12 @@ retro_core_descriptor_check_platform_group (RetroCoreDescriptor  *self,
   gchar *firmware_group;
   GError *tmp_error = NULL;
 
-  g_return_if_fail (RETRO_IS_CORE_DESCRIPTOR (self));
-  g_return_if_fail (group != NULL);
+  g_assert (group != NULL);
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                group,
-                                                RETRO_CORE_DESCRIPTOR_PLATFORM_MIME_TYPE_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          group,
+                          RETRO_CORE_DESCRIPTOR_PLATFORM_MIME_TYPE_KEY,
+                          &tmp_error);
 
   has_key = g_key_file_has_key (self->key_file,
                                 group,
@@ -343,29 +340,28 @@ retro_core_descriptor_check_platform_group (RetroCoreDescriptor  *self,
 }
 
 static void
-retro_core_descriptor_check_firmware_group (RetroCoreDescriptor  *self,
-                                            const gchar          *group,
-                                            GError              **error)
+check_firmware_group (RetroCoreDescriptor  *self,
+                      const gchar          *group,
+                      GError              **error)
 {
   GError *tmp_error = NULL;
 
-  g_return_if_fail (RETRO_IS_CORE_DESCRIPTOR (self));
-  g_return_if_fail (group != NULL);
+  g_assert (group != NULL);
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                group,
-                                                RETRO_CORE_DESCRIPTOR_FIRMWARE_PATH_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          group,
+                          RETRO_CORE_DESCRIPTOR_FIRMWARE_PATH_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
     return;
   }
 
-  retro_core_descriptor_check_has_required_key (self,
-                                                group,
-                                                RETRO_CORE_DESCRIPTOR_FIRMWARE_MANDATORY_KEY,
-                                                &tmp_error);
+  check_has_required_key (self,
+                          group,
+                          RETRO_CORE_DESCRIPTOR_FIRMWARE_MANDATORY_KEY,
+                          &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
@@ -393,7 +389,10 @@ retro_core_descriptor_has_icon (RetroCoreDescriptor  *self,
 
   g_return_val_if_fail (RETRO_IS_CORE_DESCRIPTOR (self), FALSE);
 
-  has_icon = g_key_file_has_key (self->key_file, RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP, RETRO_CORE_DESCRIPTOR_ICON_KEY, &tmp_error);
+  has_icon = g_key_file_has_key (self->key_file,
+                                 RETRO_CORE_DESCRIPTOR_LIBRETRO_GROUP,
+                                 RETRO_CORE_DESCRIPTOR_ICON_KEY,
+                                 &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_propagate_error (error, tmp_error);
 
@@ -793,10 +792,10 @@ retro_core_descriptor_get_firmware_path (RetroCoreDescriptor  *self,
                                          GError              **error)
 {
   return get_string_prefixed (self,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
-                                       firmware,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_PATH_KEY,
-                                       error);
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
+                              firmware,
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_PATH_KEY,
+                              error);
 }
 
 /**
@@ -815,10 +814,10 @@ retro_core_descriptor_get_firmware_md5 (RetroCoreDescriptor  *self,
                                         GError              **error)
 {
   return get_string_prefixed (self,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
-                                       firmware,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_MD5_KEY,
-                                       error);
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
+                              firmware,
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_MD5_KEY,
+                              error);
 }
 
 /**
@@ -837,10 +836,10 @@ retro_core_descriptor_get_firmware_sha512 (RetroCoreDescriptor  *self,
                                            GError              **error)
 {
   return get_string_prefixed (self,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
-                                       firmware,
-                                       RETRO_CORE_DESCRIPTOR_FIRMWARE_SHA512_KEY,
-                                       error);
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX,
+                              firmware,
+                              RETRO_CORE_DESCRIPTOR_FIRMWARE_SHA512_KEY,
+                              error);
 }
 
 /**
@@ -966,7 +965,7 @@ retro_core_descriptor_new (const gchar  *filename,
     return NULL;
   }
 
-  retro_core_descriptor_check_libretro_group (self, &tmp_error);
+  check_libretro_group (self, &tmp_error);
   if (G_UNLIKELY (tmp_error != NULL)) {
     g_object_unref (self);
     g_propagate_error (error, tmp_error);
@@ -978,7 +977,7 @@ retro_core_descriptor_new (const gchar  *filename,
   for (i = 0; i < groups_length; i++) {
     if (g_str_has_prefix (groups[i],
                           RETRO_CORE_DESCRIPTOR_PLATFORM_GROUP_PREFIX)) {
-      retro_core_descriptor_check_platform_group (self, groups[i], &tmp_error);
+      check_platform_group (self, groups[i], &tmp_error);
       if (G_UNLIKELY (tmp_error != NULL)) {
         g_strfreev (groups);
         g_object_unref (self);
@@ -989,7 +988,7 @@ retro_core_descriptor_new (const gchar  *filename,
     }
     else if (g_str_has_prefix (groups[i],
                                RETRO_CORE_DESCRIPTOR_FIRMWARE_GROUP_PREFIX)) {
-      retro_core_descriptor_check_firmware_group (self, groups[i], &tmp_error);
+      check_firmware_group (self, groups[i], &tmp_error);
       if (G_UNLIKELY (tmp_error != NULL)) {
         g_strfreev (groups);
         g_object_unref (self);
