@@ -1,5 +1,12 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
+/**
+ * PRIVATE:retro-gl-display
+ * @short_description: A widget rendering the video output from a core via OpenGL
+ * @title: RetroGLDisplay
+ * @stability: Private
+ */
+
 #include "retro-gl-display-private.h"
 
 #include <epoxy/gl.h>
@@ -7,6 +14,8 @@
 #include "retro-pixbuf.h"
 #include "retro-pixdata.h"
 
+#define RETRO_VIDEO_FILTER_COUNT (RETRO_VIDEO_FILTER_CRT + 1)
+
 struct _RetroGLDisplay
 {
   GtkGLArea parent_instance;
@@ -15,10 +24,9 @@ struct _RetroGLDisplay
   GdkPixbuf *pixbuf;
   RetroVideoFilter filter;
   gfloat aspect_ratio;
-  gulong on_video_output_id;
+  gulong video_output_cb_id;
 
   RetroGLSLFilter *glsl_filter[RETRO_VIDEO_FILTER_COUNT];
-  GLuint framebuffer;
   GLuint texture;
 };
 
@@ -46,15 +54,15 @@ static GLuint elements[] = {
 };
 
 static const gchar *filter_uris[] = {
-  NULL,
-  NULL,
+  "resource:///org/gnome/Retro/glsl-filters/bicubic.filter",
+  "resource:///org/gnome/Retro/glsl-filters/sharp.filter",
   "resource:///org/gnome/Retro/glsl-filters/crt-simple.filter",
 };
 
 /* Private */
 
 static void
-retro_gl_display_clear_video (RetroGLDisplay *self)
+clear_video (RetroGLDisplay *self)
 {
   g_clear_object (&self->pixbuf);
   if (self->pixdata != NULL) {
@@ -64,13 +72,13 @@ retro_gl_display_clear_video (RetroGLDisplay *self)
 }
 
 static void
-retro_gl_display_set_pixdata (RetroGLDisplay *self,
-                              RetroPixdata   *pixdata)
+set_pixdata (RetroGLDisplay *self,
+             RetroPixdata   *pixdata)
 {
   if (self->pixdata == pixdata)
     return;
 
-  retro_gl_display_clear_video (self);
+  clear_video (self);
 
   if (pixdata != NULL)
     self->pixdata = retro_pixdata_copy (pixdata);
@@ -79,11 +87,11 @@ retro_gl_display_set_pixdata (RetroGLDisplay *self,
 }
 
 static void
-retro_gl_display_get_video_box (RetroGLDisplay *self,
-                                gdouble        *width,
-                                gdouble        *height,
-                                gdouble        *x,
-                                gdouble        *y)
+get_video_box (RetroGLDisplay *self,
+               gdouble        *width,
+               gdouble        *height,
+               gdouble        *x,
+               gdouble        *y)
 {
   gdouble w;
   gdouble h;
@@ -91,11 +99,10 @@ retro_gl_display_get_video_box (RetroGLDisplay *self,
   gdouble allocated_ratio;
   gint scale;
 
-  g_return_if_fail (RETRO_IS_GL_DISPLAY (self));
-  g_return_if_fail (width != NULL);
-  g_return_if_fail (height != NULL);
-  g_return_if_fail (x != NULL);
-  g_return_if_fail (y != NULL);
+  g_assert (width != NULL);
+  g_assert (height != NULL);
+  g_assert (x != NULL);
+  g_assert (y != NULL);
 
   scale = gtk_widget_get_scale_factor (GTK_WIDGET (self));
 
@@ -122,9 +129,9 @@ retro_gl_display_get_video_box (RetroGLDisplay *self,
 }
 
 static gboolean
-retro_gl_display_load_texture (RetroGLDisplay *self,
-                               gint           *texture_width,
-                               gint           *texture_height)
+load_texture (RetroGLDisplay *self,
+              gint           *texture_width,
+              gint           *texture_height)
 {
   glBindTexture (GL_TEXTURE_2D, self->texture);
 
@@ -154,48 +161,21 @@ retro_gl_display_load_texture (RetroGLDisplay *self,
 }
 
 static void
-retro_gl_display_blit_texture (RetroGLDisplay *self,
-                               GLenum          filter,
-                               gint            texture_width,
-                               gint            texture_height)
-{
-  gdouble w = 0.0;
-  gdouble h = 0.0;
-  gdouble x = 0.0;
-  gdouble y = 0.0;
-
-  retro_gl_display_get_video_box (self, &w, &h, &x, &y);
-
-  glBindFramebuffer(GL_READ_FRAMEBUFFER, self->framebuffer);
-  glFramebufferTexture2D(GL_READ_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
-                         GL_TEXTURE_2D, self->texture, 0);
-  glBindFramebuffer(GL_READ_FRAMEBUFFER, 0);
-
-  glBindFramebuffer (GL_READ_FRAMEBUFFER, self->framebuffer);
-  glBlitFramebuffer (0, 0,
-                     texture_width,
-                     texture_height,
-                     (GLint) x, (GLint) (y + h), (GLint) (x + w), (GLint) y,
-                     GL_COLOR_BUFFER_BIT,
-                     filter);
-  glBindFramebuffer (GL_READ_FRAMEBUFFER, 0);
-}
-
-static void
-retro_gl_display_draw_texture (RetroGLDisplay  *self,
-                               RetroGLSLFilter *filter,
-                               gint             texture_width,
-                               gint             texture_height)
+draw_texture (RetroGLDisplay  *self,
+              RetroGLSLFilter *filter,
+              gint             texture_width,
+              gint             texture_height)
 {
   GLfloat source_width, source_height;
   GLfloat target_width, target_height;
   GLfloat output_width, output_height;
+  RetroGLSLShader *shader = retro_glsl_filter_get_shader (filter);
 
-  retro_glsl_filter_use_program (filter);
+  retro_glsl_shader_use_program (shader);
 
-  retro_glsl_filter_apply_texture_params (filter);
+  retro_glsl_shader_apply_texture_params (shader);
 
-  retro_glsl_filter_set_uniform_1f (filter, "relative_aspect_ratio",
+  retro_glsl_shader_set_uniform_1f (shader, "relative_aspect_ratio",
     (gfloat) gtk_widget_get_allocated_width (GTK_WIDGET (self)) /
     (gfloat) gtk_widget_get_allocated_height (GTK_WIDGET (self)) /
     self->aspect_ratio);
@@ -207,24 +187,23 @@ retro_gl_display_draw_texture (RetroGLDisplay  *self,
   output_width = (GLfloat) gtk_widget_get_allocated_width (GTK_WIDGET (self));
   output_height = (GLfloat) gtk_widget_get_allocated_height (GTK_WIDGET (self));
 
-  retro_glsl_filter_set_uniform_4f (filter, "sourceSize[0]",
+  retro_glsl_shader_set_uniform_4f (shader, "sourceSize[0]",
                                     source_width, source_height,
                                     1.0f / source_width, 1.0f / source_height);
 
-  retro_glsl_filter_set_uniform_4f (filter, "targetSize",
+  retro_glsl_shader_set_uniform_4f (shader, "targetSize",
                                     target_width, target_height,
                                     1.0f / target_width, 1.0f / target_height);
 
-  retro_glsl_filter_set_uniform_4f (filter, "outputSize",
+  retro_glsl_shader_set_uniform_4f (shader, "outputSize",
                                     output_width, output_height,
                                     1.0f / output_width, 1.0f / output_height);
 
   glDrawElements (GL_TRIANGLES, 6, GL_UNSIGNED_INT, 0);
-
 }
 
 static void
-retro_gl_display_realize (RetroGLDisplay *self)
+realize (RetroGLDisplay *self)
 {
   GLuint vertex_buffer_object;
   GLuint vertex_array_object;
@@ -246,11 +225,9 @@ retro_gl_display_realize (RetroGLDisplay *self)
   glBufferData (GL_ELEMENT_ARRAY_BUFFER, sizeof (elements), elements, GL_STATIC_DRAW);
 
   for (filter = 0; filter < RETRO_VIDEO_FILTER_COUNT; filter++) {
-    if (filter_uris[filter] == NULL)
-      continue;
+    RetroGLSLShader *shader;
 
-    self->glsl_filter[filter] = retro_glsl_filter_new (filter_uris[filter], NULL);
-    retro_glsl_filter_prepare_program (self->glsl_filter[filter], &inner_error);
+    self->glsl_filter[filter] = retro_glsl_filter_new (filter_uris[filter], &inner_error);
     if (G_UNLIKELY (inner_error != NULL)) {
       g_critical ("Shader program %s creation failed: %s",
                   filter_uris[filter],
@@ -261,7 +238,9 @@ retro_gl_display_realize (RetroGLDisplay *self)
       continue;
     }
 
-    retro_glsl_filter_set_attribute_pointer (self->glsl_filter[filter],
+    shader = retro_glsl_filter_get_shader (self->glsl_filter[filter]);
+
+    retro_glsl_shader_set_attribute_pointer (shader,
                                              "position",
                                              sizeof (((RetroVertex *) NULL)->position) / sizeof (float),
                                              GL_FLOAT,
@@ -269,7 +248,7 @@ retro_gl_display_realize (RetroGLDisplay *self)
                                              sizeof (RetroVertex),
                                              (const GLvoid *) offsetof (RetroVertex, position));
 
-    retro_glsl_filter_set_attribute_pointer (self->glsl_filter[filter],
+    retro_glsl_shader_set_attribute_pointer (shader,
                                              "texCoord",
                                              sizeof (((RetroVertex *) NULL)->texture_coordinates) / sizeof (float),
                                              GL_FLOAT,
@@ -278,10 +257,6 @@ retro_gl_display_realize (RetroGLDisplay *self)
                                              (const GLvoid *) offsetof (RetroVertex, texture_coordinates));
   }
 
-  glDeleteFramebuffers (1, &self->framebuffer);
-  self->framebuffer = 0;
-  glGenFramebuffers(1, &self->framebuffer);
-
   glDeleteTextures (1, &self->texture);
   self->texture = 0;
   glGenTextures (1, &self->texture);
@@ -291,21 +266,21 @@ retro_gl_display_realize (RetroGLDisplay *self)
     RETRO_VIDEO_FILTER_SMOOTH :
     self->filter;
 
-  if (self->glsl_filter[filter] != NULL)
-    retro_glsl_filter_use_program (self->glsl_filter[filter]);
+  if (self->glsl_filter[filter] != NULL) {
+    RetroGLSLShader *shader = retro_glsl_filter_get_shader (self->glsl_filter[filter]);
+    retro_glsl_shader_use_program (shader);
+  }
 
   glClearColor (0, 0, 0, 1);
 }
 
 static void
-retro_gl_display_unrealize (RetroGLDisplay *self)
+unrealize (RetroGLDisplay *self)
 {
   RetroVideoFilter filter;
 
   gtk_gl_area_make_current (GTK_GL_AREA (self));
 
-  glDeleteFramebuffers (1, &self->framebuffer);
-  self->framebuffer = 0;
   glDeleteTextures (1, &self->texture);
   self->texture = 0;
   for (filter = 0; filter < RETRO_VIDEO_FILTER_COUNT; filter++)
@@ -313,42 +288,24 @@ retro_gl_display_unrealize (RetroGLDisplay *self)
 }
 
 static gboolean
-retro_gl_display_render (RetroGLDisplay *self)
+render (RetroGLDisplay *self)
 {
   RetroVideoFilter filter;
   gint texture_width;
   gint texture_height;
 
-  g_return_val_if_fail (RETRO_IS_GL_DISPLAY (self), FALSE);
-
   glClear (GL_COLOR_BUFFER_BIT);
 
   filter = self->filter >= RETRO_VIDEO_FILTER_COUNT ?
     RETRO_VIDEO_FILTER_SMOOTH :
     self->filter;
 
-  if (!retro_gl_display_load_texture (self, &texture_width, &texture_height))
+  g_assert (self->glsl_filter[filter] != NULL);
+
+  if (!load_texture (self, &texture_width, &texture_height))
     return FALSE;
 
-  if (filter == RETRO_VIDEO_FILTER_SMOOTH) {
-    retro_gl_display_blit_texture (self, GL_LINEAR, texture_width, texture_height);
-
-    return FALSE;
-  }
-
-  if (filter == RETRO_VIDEO_FILTER_SHARP) {
-    retro_gl_display_blit_texture (self, GL_NEAREST, texture_width, texture_height);
-
-    return FALSE;
-  }
-
-  if (self->glsl_filter[filter] == NULL) {
-    retro_gl_display_blit_texture (self, GL_LINEAR, texture_width, texture_height);
-
-    return FALSE;
-  }
-
-  retro_gl_display_draw_texture (self, self->glsl_filter[filter], texture_width, texture_height);
+  draw_texture (self, self->glsl_filter[filter], texture_width, texture_height);
 
   return FALSE;
 }
@@ -382,58 +339,46 @@ retro_gl_display_class_init (RetroGLDisplayClass *klass)
   gtk_widget_class_set_css_name (widget_class, "retrogldisplay");
 }
 
-static void
-queue_draw (GObject    *sender,
-            GParamSpec *pspec,
-            gpointer    self)
-{
-  gtk_widget_queue_draw (GTK_WIDGET (self));
-}
-
 static void
 retro_gl_display_init (RetroGLDisplay *self)
 {
   g_signal_connect_object (G_OBJECT (self),
                            "realize",
-                           (GCallback) retro_gl_display_realize,
-                           GTK_WIDGET (self),
+                           (GCallback) realize,
+                           self,
                            0);
 
   g_signal_connect_object (G_OBJECT (self),
                            "unrealize",
-                           (GCallback) retro_gl_display_unrealize,
-                           GTK_WIDGET (self),
+                           (GCallback) unrealize,
+                           self,
                            0);
 
   g_signal_connect_object (G_OBJECT (self),
                            "render",
-                           (GCallback) retro_gl_display_render,
-                           GTK_WIDGET (self),
+                           (GCallback) render,
+                           self,
                            0);
 
   self->filter = RETRO_VIDEO_FILTER_SMOOTH;
 
   g_signal_connect_object (G_OBJECT (self),
                            "notify::sensitive",
-                           (GCallback) queue_draw,
-                           GTK_WIDGET (self),
-                           0);
+                           (GCallback) gtk_widget_queue_draw,
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 static void
-retro_gl_display_on_video_output (RetroCore    *sender,
-                                  RetroPixdata *pixdata,
-                                  gpointer      user_data)
+video_output_cb (RetroCore      *sender,
+                 RetroPixdata   *pixdata,
+                 RetroGLDisplay *self)
 {
-  RetroGLDisplay *self = RETRO_GL_DISPLAY (user_data);
-
-  g_return_if_fail (RETRO_IS_GL_DISPLAY (self));
-
   if (pixdata == NULL)
     return;
 
   self->aspect_ratio = retro_pixdata_get_aspect_ratio (pixdata);
-  retro_gl_display_set_pixdata (self, pixdata);
+  set_pixdata (self, pixdata);
 }
 
 /* Public */
@@ -455,13 +400,13 @@ retro_gl_display_set_core (RetroGLDisplay *self,
     return;
 
   if (self->core != NULL) {
-    g_signal_handler_disconnect (G_OBJECT (self->core), self->on_video_output_id);
+    g_signal_handler_disconnect (G_OBJECT (self->core), self->video_output_cb_id);
     g_clear_object (&self->core);
   }
 
   if (core != NULL) {
     self->core = g_object_ref (core);
-    self->on_video_output_id = g_signal_connect_object (core, "video-output", (GCallback) retro_gl_display_on_video_output, self, 0);
+    self->video_output_cb_id = g_signal_connect_object (core, "video-output", (GCallback) video_output_cb, self, 0);
   }
 }
 
@@ -508,7 +453,7 @@ retro_gl_display_set_pixbuf (RetroGLDisplay *self,
   if (self->pixbuf == pixbuf)
     return;
 
-  retro_gl_display_clear_video (self);
+  clear_video (self);
 
   if (pixbuf != NULL)
     self->pixbuf = g_object_ref (pixbuf);
@@ -567,7 +512,7 @@ retro_gl_display_get_coordinates_on_display (RetroGLDisplay *self,
   g_return_val_if_fail (display_x != NULL, FALSE);
   g_return_val_if_fail (display_y != NULL, FALSE);
 
-  retro_gl_display_get_video_box (self, &w, &h, &x, &y);
+  get_video_box (self, &w, &h, &x, &y);
 
   scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (self));
   widget_x *= scale_factor;
