@@ -1,5 +1,12 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
+/**
+ * SECTION:retro-module-query
+ * @short_description: An object to query the available Libretro cores
+ * @title: RetroModuleQuery
+ * @See_also: #RetroCoreDescriptor, #RetroModuleIterator
+ */
+
 #include "retro-module-query.h"
 
 #include "../retro-gtk-config.h"
@@ -36,7 +43,7 @@ retro_module_query_init (RetroModuleQuery *self)
 }
 
 static gchar **
-retro_module_query_get_plugin_lookup_paths ()
+get_plugin_lookup_paths (void)
 {
   gchar **envp;
   const gchar *env_plugin_path;
@@ -77,7 +84,7 @@ retro_module_query_iterator (RetroModuleQuery *self)
 
   g_return_val_if_fail (RETRO_IS_MODULE_QUERY (self), NULL);
 
-  paths = retro_module_query_get_plugin_lookup_paths ();
+  paths = get_plugin_lookup_paths ();
   result = retro_module_iterator_new ((const gchar * const *) paths,
                                       self->recursive);
   g_strfreev (paths);
