@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_OPTION_ITERATOR_H
-#define RETRO_OPTION_ITERATOR_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
@@ -21,5 +20,3 @@ gboolean retro_option_iterator_next (RetroOptionIterator  *self,
                                      RetroOption         **option);
 
 G_END_DECLS
-
-#endif /* RETRO_OPTION_ITERATOR_H */
