@@ -20,6 +20,7 @@
 
 #include "retro-reftest-file.h"
 #include "retro-test-controller.h"
+#include <glib/gstdio.h>
 
 typedef struct {
   guint refs;
@@ -61,8 +62,6 @@ static const GOptionEntry test_args[] = {
 
 static RetroReftestData *
 retro_reftest_data_ref (RetroReftestData *self) {
-  g_return_val_if_fail (self != NULL, NULL);
-
   self->refs++;
 
   return self;
@@ -70,8 +69,6 @@ retro_reftest_data_ref (RetroReftestData *self) {
 
 static void
 retro_reftest_data_unref (RetroReftestData *self) {
-  g_return_if_fail (self != NULL);
-
   if (self->refs == 0) {
     g_object_unref (self->core);
     retro_pixdata_free (self->pixdata);
@@ -87,8 +84,6 @@ retro_reftest_data_unref (RetroReftestData *self) {
 
 static void
 retro_reftest_options_unref (RetroReftestOptions *self) {
-  g_return_if_fail (self != NULL);
-
   if (self->refs == 0) {
     retro_reftest_data_unref (self->data);
     g_hash_table_unref (self->options);
@@ -102,8 +97,6 @@ retro_reftest_options_unref (RetroReftestOptions *self) {
 
 static void
 retro_reftest_run_unref (RetroReftestRun *self) {
-  g_return_if_fail (self != NULL);
-
   if (self->refs == 0) {
     retro_reftest_data_unref (self->data);
     if (self->controller_states != NULL)
@@ -118,8 +111,6 @@ retro_reftest_run_unref (RetroReftestRun *self) {
 
 static void
 retro_reftest_video_unref (RetroReftestVideo *self) {
-  g_return_if_fail (self != NULL);
-
   if (self->refs == 0) {
     retro_reftest_data_unref (self->data);
     g_object_unref (self->video_file);
@@ -259,8 +250,8 @@ pixdata_equal (GdkPixbuf  *test,
 }
 
 static void
-retro_reftest_on_video_output (RetroReftestData *data,
-                               RetroPixdata     *pixdata)
+video_output_cb (RetroReftestData *data,
+                 RetroPixdata     *pixdata)
 {
   if (pixdata == NULL)
     return;
@@ -355,7 +346,7 @@ retro_reftest_test_fast_forward (RetroReftestRun *run)
   g_assert_cmpuint (next_frame, <, target_frame);
 
   for (; next_frame < target_frame; next_frame++)
-    retro_core_run (run->data->core);
+    retro_core_iteration (run->data->core);
 
   run->data->next_frame = next_frame;
 
@@ -398,7 +389,7 @@ retro_reftest_test_run (RetroReftestRun *run)
     }
   }
 
-  retro_core_run (run->data->core);
+  retro_core_iteration (run->data->core);
   next_frame++;
 
   run->data->next_frame = next_frame;
@@ -416,7 +407,7 @@ retro_reftest_test_state_none (RetroReftestData *data)
 static void
 retro_reftest_test_state_refresh (RetroReftestData *data)
 {
-  GBytes *state;
+  g_autofree gchar *filename = NULL, *tmpname = NULL;
   GError *error = NULL;
 
   if (!retro_core_get_can_access_state (data->core)) {
@@ -425,12 +416,15 @@ retro_reftest_test_state_refresh (RetroReftestData *data)
     return;
   }
 
-  state = retro_core_get_state (data->core, &error);
+  tmpname = g_strdup_printf ("retro-reftest-state-%d", g_random_int ());
+  filename = g_build_filename (g_get_tmp_dir (), tmpname, NULL);
+
+  retro_core_save_state (data->core, filename, &error);
   g_assert_no_error (error);
-  retro_core_set_state (data->core, state, &error);
+  retro_core_load_state (data->core, filename, &error);
   g_assert_no_error (error);
 
-  g_bytes_unref (state);
+  g_remove (filename);
 }
 
 static void
@@ -703,7 +697,7 @@ retro_reftest_setup_for_file (GFile *file)
   g_list_free (frames);
   retro_reftest_data_unref (data);
 
-  g_signal_connect_swapped (data->core, "video-output", (GCallback) retro_reftest_on_video_output, data);
+  g_signal_connect_swapped (data->core, "video-output", (GCallback) video_output_cb, data);
 }
 
 int
